@@ -3,13 +3,10 @@ __all__ = ('CacheMixin', 'CacheObjectMixin')
 import os
 from typing import Union
 
-from django.contrib.auth import get_user_model
 from django.core.cache import cache
 
 from expressmoney.api.utils import log
 
-User = get_user_model()
-
 
 class BaseCacheMixin:
     _cache_period: int = None
@@ -83,7 +80,7 @@ class GetCacheMixin:
 class CacheMixin(GetCacheMixin, BaseCacheMixin):
 
     def __init__(self,
-                 user: User,
+                 user,
                  query_params: dict = None,
                  is_async: bool = False,
                  timeout: tuple = (30, 30)
@@ -111,7 +108,7 @@ class CacheMixin(GetCacheMixin, BaseCacheMixin):
 class CacheObjectMixin(GetCacheMixin, BaseCacheMixin):
 
     def __init__(self,
-                 user: User,
+                 user,
                  lookup_field_value: Union[str, int],
                  is_async: bool = False,
                  timeout: tuple = (30, 30)
